
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off


*------------------------------------------------------------------------------*
*[1] % of post-conflict cases with PGM presence inherited (old) from the conflict 
* % of conflict-episodes per p-c year
*------------------------------------------------------------------------------*

*-------------------
* Opend dataset 
*-------------------
clear
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year


** Identify complete spells and not those that are chopped prior 1981
	drop if peace_years>10
	sum peace_years
	sum year

	
** Collapse data by post-conflict episode year
** Keep the maximum value for the variables of interest.
	#delimit ;
	collapse (max) 	pgm_presence 			// overall presence
					pgm_presence_count
					pgm_warlegacy_dummy
					pgm_warlegacy_count
					gwno
			, by(peace_id peace_years)
	;
	#delimit cr


	
	
*------------------------------
** Estimations for the plot
*------------------------------

** Generate a count of countries per peace_year
	drop if pgm_warlegacy_dummy == .


** Generate a count to know how many countries each post-conflict year
	gen count = 1


* Count of post-conflict episode by war legacy presence
	#delimit ;
	collapse (sum) count 
				   pgm_warlegacy_count
				   pgm_presence_count
			, by(pgm_warlegacy_dummy peace_years)
	;
	#delimit cr


	sort peace_years
	egen total = sum(count), by(peace_years)

** Generate percentages
	gen percent_episode = (count*100)/total

	

*------------------------------
** Plot
*------------------------------

** Generate min value for bars
	gen min = 0


** % of pc-country-year with PGMs that are war legacies
	keep if pgm_warlegacy_dummy == 1


	#delimit ;
	twoway  rbar  min percent_episode peace_years, col(gs0) barwidth(.5) 
			title("", size(medlarge) ring(10)) 
			xtitle("Post-conflict years", size(large) height(15))
			ytitle("Percentage of post-conflict episodes", size(medlarge) orientation(vertical) height(5))
			yscale(range(0 50))
			xscale(range(1 10))
			ylabel(0(5)50, angle(horizontal) nogrid labsize(medsmall)) ymtick(##10)
			xlabel(1(1)10, angle(horizontal) nogrid labsize(medsmall)) ymtick(##10)
			legend(off)
			text(-8 1  "(n=53)", size(medsmall))
			text(-8 2  "(n=41)", size(medsmall))
			text(-8 3  "(n=34)", size(medsmall))
			text(-8 4  "(n=28)", size(medsmall))
			text(-8 5  "(n=22)", size(medsmall))
			text(-8 6  "(n=18)", size(medsmall))
			text(-8 7  "(n=15)", size(medsmall))
			text(-8 8  "(n=12)", size(medsmall))
			text(-8 9  "(n=11)", size(medsmall))
			text(-8 10 "(n=10)", size(medsmall))
			plotregion(lc(black) ls(solid) lw(vthin)) 
			ysize(1) xsize(1.5)  
			graphregion(margin(medium) color(white)) 
			scheme(s2mono)
	;
	# delimit cr

	
** Save graph
graph export "Figures/cg_postconflict_pgm_old_Figure2.a.pdf", as(pdf) replace







*------------------------------------------------------------------------------*
*[2] % Of post-conflict cases with PGM presence that is new to post-conflict 
* % of conflict-episodes per p-c peace_year
*------------------------------------------------------------------------------*


*-------------------
* Opend dataset 
*-------------------
	clear
	use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
	sort	gwno year
	tsset	gwno year

** Identify complete spells and not those that are chopped prior 1981
	drop if peace_years>10
	sum peace_years
	sum year



** Collapse data by post-conflict episode year
	#delimit ;
	collapse (max) 	pgm_presence 			// overall presence
					pgm_presence_count
					pgm_new_postconf_dummy
					pgm_new_postconf_count
					gwno
			, by(peace_id peace_years)
	;
	#delimit cr


** Do the table first
	tab pgm_new_postconf_dummy peace_years, col


*------------------------------
** Estimations for the plot
*------------------------------

** Generate a count of countries per peace_year
	drop if pgm_new_postconf_dummy == .

	gen count = 1


	#delimit ;
	collapse (sum) count 	
			, by(pgm_new_postconf_dummy peace_years)
	;
	#delimit cr


	sort peace_years
	egen total = sum(count), by(peace_years)

** Generate percentages
	gen percent = (count*100)/total



*------------------------------
** Plot
*------------------------------
	gen min = 0

	*
	keep if pgm_new_postconf_dummy == 1
	*
	#delimit ;
	twoway  rbar  min percent peace_years , col(gs0) barwidth(.5) 
			title("", size(medlarge) ring(10)) 
			xtitle("Post-conflict years", size(large) height(15))
			ytitle("", orientation(vertical) height(10))
			yscale(range(0 50))
			xscale(range(1 10))
			ylabel(0(5)50, angle(horizontal) nogrid labsize(medsmall)) ymtick(##5)
			xlabel(1(1)10, angle(horizontal) nogrid labsize(medsmall)) ymtick(##10)
			legend(off)
			text(-8 1  "(n=9)", size(medsmall))
			text(-8 2  "(n=10)", size(medsmall))
			text(-8 3  "(n=12)", size(medsmall))
			text(-8 4  "(n=11)", size(medsmall))
			text(-8 5  "(n=11)", size(medsmall))
			text(-8 6  "(n=11)", size(medsmall))
			text(-8 7  "(n=13)", size(medsmall))
			text(-8 8  "(n=11)", size(medsmall))
			text(-8 9  "(n=10)", size(medsmall))
			text(-8 10 "(n=9)", size(medsmall))
			plotregion(lc(black) ls(solid) lw(vthin)) 
			ysize(1) xsize(1.5)  
			graphregion(margin(medium) color(white)) 
			scheme(s2mono)
	;
	# delimit cr
	*
	graph export "Figures/cg_postconflict_pgm_new_Figure2.b.pdf", as(pdf) replace


*------------------------------------------------------------------------------*
* End of do file
*------------------------------------------------------------------------------*
