


*------------------------------------------------------------------------------*
* Authors: 		Sabine C. Carey (University Mannheim) and 
*				Belen Gonzalez (Leuphana Universität Lüneburg and GIGA)
* Article: 		The legacy of war: The effect of militias on postwar repression
* Journal: 		Conflict Management and Peace Science (CMPS). 
* Date: 		2020
* Instructions: This master do file executes all replication do files 
*				included in this folder.
*Stata:			All estimations were done with Stata 15. 			
*------------------------------------------------------------------------------*




*--------------------
** Set your working directory to the location of this file
*--------------------
clear
set more off

** Instructions: Adapt working directory path to the location where you have 
**   			 downloaded the replication files.
**				 Do the same in line 161 of this do-file.

cd "~/Documents/Replication_CareyGonzalez_CMPS2020"


*--------------------
* Install necessary packages if needed: For this, un-comment the needed command line
*--------------------
	* For the substantive effects
		*net from https://gking.harvard.edu/clarify
		*net install clarify
	
	*For the text of the parallel assumption violation on ordered logit
		*ssc install oparallel
	
	* For the map in Figure 1
		*ssc install spmap
		*ssc install shp2dta
		*ssc install mif2dta

		
		

*--------------------
* Descriptives
*--------------------

	
	* Figure 2: Proportion of post-conflict episodes with inherited PGMs and new PGMs
	do "Descriptives/cg_barplots_pgm_presence_Figure2.do" 


	* Figure 4: Distribution of target types by pro-government militias
	do "Descriptives/cg_pgm_targets_Figure4.do" 

	
	* Table A1.1: Summary statistics (Appendix)
	do "Descriptives/cg_summary_stats.do" 
	
	
	* Figure A1.2 Average values of Political Terror Scale across peace types (Appendix)
	do "Descriptives/cg_barplots_peace_postconflict_FigureA1.2.do"
	
	
	* Figure A1.3 Frequency of post-conflict observations over time (Appendix)
	do "Descriptives/cg_barplots_sample_FigureA1.3.do"
	
	
	* Results section: text on page 20 about substitution/complementarity relations
	do "Descriptives/cg_country_profile_pgm_new.do" 
	
	
	* Table A1.4.1 Distribution of post-conflict episodes by conflict termination type
	do "Descriptives/cg_pgm_conflict_termination_TableA1.4.1.do"
	
	
	* Table A1.4.2 Distribution of post-conflict episodes with PGMs by conflict termination type
	do "Descriptives/cg_pgm_conflict_termination_pgm_TableA1.4.2.do"
	
	
	* Table A1.4.3 Distribution of post-conflict PGMs by their relation to the government
	do "Descriptives/cg_pgm_conflict_government_relations_TableA1.4.3.do" 

	

*--------------------
* Main Models
*--------------------
	
	* Table 1 Order logit estimations for the level of human rights violations 
	*         in post-conflict societies
	do "Main Models/cg_postconflict_pgm_newold.do" 
	
	

*--------------------
* Substantive effects
*--------------------

	* Figure 3 Substantive effect of conflict inherited pro-government militias 
	*		   on repression in the fifth year of post-conflict peace
	do "Substantive effects/cg_effects_pgm.do"
	
	
	* Results section (within text): Correctly predicted cases from the main models
	do "Substantive effects/cg_correctly_predicted.do" 
	
	
	* Figure A6.1 Predicted probabilities of repression with conflict inherited 
	*			  pro-government militias in the fifth year of post-conflict peace
	do "Substantive effects/cg_predicted_probabilities_pgms_old.do" 

	
	
	
	
*--------------------
* Robustness tests - Appendix 
*--------------------

	* A2.1 OLS estimations for the level of human rights violations
	do "Robustness/cg_robustness_ols.do" 
	
	
	* Table A3.1 Models with step-wise exclusionary criteria for post-conflict duration
	do "Robustness/cg_robustness_jacknife.do" 
	
	
	* A4.1 Models with the log of the number of pro-government militias
	do "Robustness/cg_robustness_log.do"
	
	
	* A5.1 Models with pro-government militias
	do "Robustness/cg_postconflict_pgm.do"
	
	
	* A5.2 Models with semi-official and informal pro-governmen militias
	do "Robustness/cg_robustness_pgm_infsemi.do" 
	
	 
	* A5.3 Models with additional control variables
	do "Robustness/cg_robustness_extra_controls.do" 
	
	
	* A5.4 Models including post-conflict episodes with rebel victory
	do "Robustness/cg_robustness_rebelvictories.do" 
	
	

*--------------------
* Descriptives: Map
*--------------------

	* Re-iterate the working directory where the replication files have been
	* store to be able to replicate the map.
	cd "~/Documents/Replication_CareyGonzalez_CMPS2020"

	* Figure 1 Post-conflict countries and levels of physical integrity rights 
	*		   violations 1981-2014
	do "Map/cg_repression_map.do" 

	



*------------------------------------------------------------------------------*
* End of Do file
*------------------------------------------------------------------------------*
