

*-------------------------------------------------------------------------------
* Model (1) PGMs INHARITED FROM CONFLICT (count) 0 -> 1
*-------------------------------------------------------------------------------
*
*-------------------
* Prepare working space
*-------------------
clear	all
set		more off
version 14.2


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year


*
* Run model 
set seed 15935746
#delimit ;
estsimp ologit 	   pts_alt 
				   pgm_warlegacy_count
				   pgm_new_postconf_count
				   xconst      
				   ptsL1_alt
				   media_free_lag
				   pko 
				   gov_change_L1
				   rgdppc_log
				   pop_log
				   peace_years 
				   peace_years2 
				   peace_years3
				   if peace_years<=5, cl(gwno)
;
#delimit cr


*- Set values: PROBABILITY OF REPRESSION GIVEN THAT PEACE IS AT YEAR 5
*Pr(Y=1-2,3,4-5) when there are no PGMs

	#delimit ;
	setx pgm_warlegacy_count		 0
		 pgm_new_postconf_count		 0
		 peace_years				 5	
		 peace_years2  				 .25
		 peace_years3 				 1.25
		(media_free_lag 
		 pko 
		 gov_change_L1
		 ptsL1_alt
		 xconst) 	 median 
		(pop_log 
		 rgdppc_log
		 xconst) 	 mean 
	;
	#delimit cr
	setx
	simqi, prval(2 3 4) genpr(pr2_pgm0 pr3_pgm0 pr4_pgm0)	 
	*


*Pr(Y=1-2,3,4-5) when there ARE PGMs
	#delimit ;
	setx pgm_warlegacy_count    	 1  
		 pgm_new_postconf_count		 0
		 peace_years				 5	
		 peace_years2  				 .25
		 peace_years3 				 1.25
		(media_free_lag 
		 pko 
		 gov_change_L1
		 ptsL1_alt
		 xconst) 	 			median 
		(pop_log 
		 rgdppc_log
		 xconst) 	 			mean 
	;
	#delimit cr
	setx
	simqi, prval(2 3 4) genpr( pr2_pgm1 pr3_pgm1 pr4_pgm1)	 

	
** Generate difference 0->1
	forval i=2/4 {
	gen dipr`i'_pgm=pr`i'_pgm1 - pr`i'_pgm0
	}



** Keep quantities of interest
	keep dipr*

	foreach var of varlist dipr*{
	sum `var'
	quietly gen mean_`var'=r(mean) in 1
	quietly _pctile `var', p(2.5,5.0,95.0,97.5)
	gen p25_`var'=r(r1) in 1
	gen p50_`var'=r(r2) in 1
	gen p95_`var'=r(r3) in 1
	gen p975_`var'=r(r4) in 1
	}

	keep mean* p25* p50* p95* p975* 
	keep in 1
	gen id=1

	
** Re-shape data for plot
	reshape long mean@ p25@ p50@ p95@ p975@, i(id) string
	split _j, gen(var) parse("_")
	drop id _j var1

	gen plot=.
	replace plot=1 if var2=="dipr2" | ///
					  var2=="dipr3" | ///
					  var2=="dipr4" 
	replace plot=3 if plot>2



**Plotting Pr(PTS=1, 2, 3, 4, 5)
	gen xaxis=.
	replace xaxis = 2 if var2 == "dipr2"
	replace xaxis = 3 if var2 == "dipr3"
	replace xaxis = 4 if var2 == "dipr4"


	#delimit ;		
	twoway rspike p25 p975 xaxis if plot==1,  lcolor(gs0) lwidth(thin)  // 95 CI
		  || rspike p50 p95 xaxis if plot==1, lcolor(gs0) lwidth(thick)   // 90 CI
		  || scatter  mean xaxis if plot==1,
					  msymbol(O) msize(large) mlwidth(medthick) mfcolor(gs14) color(gs0)
					 //
					 yscale(range(-0.15 0.15) noline titlegap(*-10)) 
					 xscale(range(1.5 4.5) noline titlegap(*+10))
					 yline(0,lpattern(shortdash) lwidth(thin) lcolor(black))
					 ylabel(-.20  "-20%"
							-.15  "-15%"
							-.1  "-10%" 
							-.05 "-5%"
							   0 "0%"
							 .05 "5%"
							 .1  "10%"
							 .15  "15%"
							 .20  "20%", labsize(small) angle(horizontal) nogrid) ymtick(##10)
					 xlabel(2 "Non or limited" 3 "Extensive" 4 "Widespread", angle(horizontal) nogrid labsize(medsmall))
					 //
					 title("No PGM {&rarr} 1 PGM", size(medsmall) margin(medsmall) box bexpand fc(gs14) lw(thin) linegap(2))
					 xtitle("", size(medium)) 
					 ysize(1) xsize(1)
					 legend(off)
					 scheme(s2mono) plotregion(lcolor(black)) 
					 graphregion(fcolor(white) ilcolor(white) lcolor(white))
					 saving(PGMold01, replace)
					 ; 
	#delimit cr	




*-------------------------------------------------------------------------------
* Model (1) PGMs INHARITED FROM CONFLICT (count) 0 -> 2
*-------------------------------------------------------------------------------
*
*-------------------
* Prepare working space
*-------------------
clear	all
set		more off
version 14.2


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*
* Run model
set seed 15935746
#delimit ;
estsimp ologit 	   pts_alt 
				   pgm_warlegacy_count
				   pgm_new_postconf_count
				   xconst      
				   ptsL1_alt
				   media_free_lag
				   pko 
				   gov_change_L1
				   rgdppc_log
				   pop_log
				   peace_years 
				   peace_years2 
				   peace_years3
				   if peace_years<=5, cl(gwno)
;
#delimit cr


*- Set values: PROBABILITY OF REPRESSION GIVEN THAT PEACE IS AT YEAR 5

*Pr(Y=1-2,3,4-5) when there are no PGMs 
	#delimit ;
	setx pgm_warlegacy_count		 0
		 pgm_new_postconf_count		 0
		 peace_years				 5	
		 peace_years2  				 .25
		 peace_years3 				 1.25
		(media_free_lag 
		 pko 
		 gov_change_L1
		 ptsL1_alt
		 xconst) 	 median 
		(pop_log 
		 rgdppc_log
		 xconst) 	 mean 
	;
	#delimit cr
	setx
	simqi, prval(2 3 4) genpr(pr2_pgm0 pr3_pgm0 pr4_pgm0)	 

	
	
*Pr(Y=1-2,3,4-5) when there ARE PGMs 
	#delimit ;
	setx pgm_warlegacy_count    	 2  
		 pgm_new_postconf_count		 0
		 peace_years				 5	
		 peace_years2  				 .25
		 peace_years3 				 1.25
		(media_free_lag 
		 pko 
		 gov_change_L1
		 ptsL1_alt
		 xconst) 	 			median 
		(pop_log 
		 rgdppc_log
		 xconst) 	 			mean 
	;
	#delimit cr
	setx
	simqi, prval(2 3 4) genpr( pr2_pgm1 pr3_pgm1 pr4_pgm1)	 

	
	
** Calculate differences 0->2
	forval i=2/4 {
	gen dipr`i'_pgm=pr`i'_pgm1 - pr`i'_pgm0
	}



** Keep relevant information
	keep dipr*

	foreach var of varlist dipr*{
	sum `var'
	quietly gen mean_`var'=r(mean) in 1
	quietly _pctile `var', p(2.5,5.0,95.0,97.5)
	gen p25_`var'=r(r1) in 1
	gen p50_`var'=r(r2) in 1
	gen p95_`var'=r(r3) in 1
	gen p975_`var'=r(r4) in 1
	}

	keep mean* p25* p50* p95* p975* 
	keep in 1
	gen id=1

	
** Re-shape data for plot
	reshape long mean@ p25@ p50@ p95@ p975@, i(id) string
	split _j, gen(var) parse("_")
	drop id _j var1

	
** Generate space between quantities of interest
	gen plot=.
	replace plot=1 if var2=="dipr2" | ///
					  var2=="dipr3" | ///
					  var2=="dipr4" 
	replace plot=3 if plot>2

	
	
*Plotting Pr(PTS=1, 2, 3, 4, 5)
	gen xaxis=.
	replace xaxis = 2 if var2 == "dipr2"
	replace xaxis = 3 if var2 == "dipr3"
	replace xaxis = 4 if var2 == "dipr4"


	#delimit ;		
	twoway rspike p25 p975 xaxis if plot==1,  lcolor(gs0) lwidth(thin)  // 95 CI
		  || rspike p50 p95 xaxis if plot==1, lcolor(gs0) lwidth(thick)   // 90 CI
		  || scatter  mean xaxis if plot==1,
					  msymbol(O) msize(large) mlwidth(medthick) mfcolor(gs14) color(gs0)
					 //
					 yscale(range(-0.15 0.15) noline titlegap(*-10)) 
					 xscale(range(1.5 4.5) noline titlegap(*+10))
					 yline(0,lpattern(shortdash) lwidth(thin) lcolor(black))
					 ylabel(-.20  "-20%"
							-.15  "-15%"
							-.1  "-10%" 
							-.05 "-5%"
							   0 "0%"
							 .05 "5%"
							 .1  "10%"
							 .15  "15%"
							 .20  "20%", labsize(small) angle(horizontal) nogrid) ymtick(##10)
					 xlabel(2 "Non or limited" 3 "Extensive" 4 "Widespread", angle(horizontal) nogrid labsize(medsmall))
					 //
					 title("No PGM {&rarr} 2 PGMs", size(medsmall) margin(medsmall) box bexpand fc(gs14) lw(thin) linegap(2))
					 xtitle("", size(medium)) 
					 ysize(1) xsize(1)
					 legend(off)
					 scheme(s2mono) plotregion(lcolor(black)) 
					 graphregion(fcolor(white) ilcolor(white) lcolor(white))
					 saving(PGMold02, replace)
					 ; 
	#delimit cr	






*-------------------------------------------------------------------------------
* Model (1): PGMs INHARITED FROM CONFLICT (count) 0 -> 3
*-------------------------------------------------------------------------------
*-------------------
* Prepare working space
*-------------------
clear	all
set		more off
version 14.2


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*
* Run model
set seed 15935746
#delimit ;
estsimp ologit 	   pts_alt 
				   pgm_warlegacy_count
				   pgm_new_postconf_count
				   xconst      
				   ptsL1_alt
				   media_free_lag
				   pko 
				   gov_change_L1
				   rgdppc_log
				   pop_log
				   peace_years 
				   peace_years2 
				   peace_years3
				   if peace_years<=5, cl(gwno)
;
#delimit cr


*- Set values: PROBABILITY OF REPRESSION GIVEN THAT PEACE IS AT YEAR 5

*Pr(Y=1-2,3,4-5) when there are no PGMs 
	#delimit ;
	setx pgm_warlegacy_count		 0
		 pgm_new_postconf_count		 0
		 peace_years				 5	
		 peace_years2  				 .25
		 peace_years3 				 1.25
		(media_free_lag 
		 pko 
		 gov_change_L1
		 ptsL1_alt
		 xconst) 	 median 
		(pop_log 
		 rgdppc_log
		 xconst) 	 mean 
	;
	#delimit cr
	setx
	simqi, prval(2 3 4) genpr(pr2_pgm0 pr3_pgm0 pr4_pgm0)	 
	*


*Pr(Y=1-2,3,4-5) when there ARE PGMs
	#delimit ;
	setx pgm_warlegacy_count    	 3 
		 pgm_new_postconf_count		 0
		 peace_years				 5	
		 peace_years2  				 .25
		 peace_years3 				 1.25
		(media_free_lag 
		 pko 
		 gov_change_L1
		 ptsL1_alt
		 xconst) 	 			median 
		(pop_log 
		 rgdppc_log
		 xconst) 	 			mean 
	;
	#delimit cr
	setx
	simqi, prval(2 3 4) genpr( pr2_pgm1 pr3_pgm1 pr4_pgm1)	 

	
	
* Calculate the difference 0->3
	forval i=2/4 {
	gen dipr`i'_pgm=pr`i'_pgm1 - pr`i'_pgm0
	}

	
** Keep relevant information
	keep dipr*

	foreach var of varlist dipr*{
	sum `var'
	quietly gen mean_`var'=r(mean) in 1
	quietly _pctile `var', p(2.5,5.0,95.0,97.5)
	gen p25_`var'=r(r1) in 1
	gen p50_`var'=r(r2) in 1
	gen p95_`var'=r(r3) in 1
	gen p975_`var'=r(r4) in 1
	}

	keep mean* p25* p50* p95* p975* 
	keep in 1
	gen id=1
	
	
	
** Re-shape data for plot
	reshape long mean@ p25@ p50@ p95@ p975@, i(id) string
	split _j, gen(var) parse("_")
	drop id _j var1

	
* Generate distance between them
	gen plot=.
	replace plot=1 if var2=="dipr2" | ///
					  var2=="dipr3" | ///
					  var2=="dipr4" 
	replace plot=3 if plot>2

*Plotting Pr(PTS=1, 2, 3, 4, 5)
	gen xaxis=.
	replace xaxis = 2 if var2 == "dipr2"
	replace xaxis = 3 if var2 == "dipr3"
	replace xaxis = 4 if var2 == "dipr4"



	#delimit ;		
	twoway rspike p25 p975 xaxis if plot==1,  lcolor(gs0) lwidth(thin)  // 95 CI
		  || rspike p50 p95 xaxis if plot==1, lcolor(gs0) lwidth(thick)   // 90 CI
		  || scatter  mean xaxis if plot==1,
					  msymbol(O) msize(large) mlwidth(medthick) mfcolor(gs14) color(gs0)
					 //
					 yscale(range(-0.15 0.15) noline titlegap(*-10)) 
					 xscale(range(1.5 4.5) noline titlegap(*+10))
					 yline(0,lpattern(shortdash) lwidth(thin) lcolor(black))
					 ylabel(-.20  "-20%"
							-.15  "-15%"
							-.1  "-10%" 
							-.05 "-5%"
							   0 "0%"
							 .05 "5%"
							 .1  "10%"
							 .15  "15%"
							 .20  "20%", labsize(small) angle(horizontal) nogrid) ymtick(##10)
					 xlabel(2 "Non or limited" 3 "Extensive" 4 "Widespread", angle(horizontal) nogrid labsize(medsmall))
					 //
					 title("No PGM {&rarr} 3 PGMs", size(medsmall) margin(medsmall) box bexpand fc(gs14) lw(thin) linegap(2))
					 xtitle("", size(medium)) 
					 ysize(1) xsize(1)
					 legend(off)
					 scheme(s2mono) plotregion(lcolor(black)) 
					 graphregion(fcolor(white) ilcolor(white) lcolor(white))
					 saving(PGMold03, replace)
					 ; 
	#delimit cr	






*-------------------------------------------------------------------------------
* Combine plots
*-------------------------------------------------------------------------------

# delimit ;
gr combine PGMold01.gph PGMold02.gph PGMold03.gph, 
	cols(3)
	title("Change in probability of""physical integrity rights violations", 
	       ring(1) position(9) orientation(vertical) size(small) linegap(2)
		   margin(r=2))
	subtitle("Physical integrity rights violations", 
	       ring(1) position(6) orientation(horizontal) size(small) linegap(2)
		   margin(r=2))
	ysize(1) xsize(2)
	plotregion(margin(small) lc(black) ls(solid) lw(vthin) col(white)) 
	graphregion(col(white) lcolor(white) lalign(outside))
	scheme(s2mono)
	imargin(0 8 0 0)
;
#delimit cr

graph export "Figures/cg_effects_pgm.pdf", as(pdf) replace

erase PGMold01.gph 
erase PGMold02.gph 
erase PGMold03.gph


*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
